pm4py.algo.discovery.transition\_system.variants package
========================================================

Submodules
----------

pm4py.algo.discovery.transition\_system.variants.view\_based module
-------------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.transition_system.variants.view_based
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.transition_system.variants
   :members:
   :undoc-members:
   :show-inheritance:
